@@ -341,6 +341,11 @@ def parse_args(args=None):
         default='all',
         help="control how to pretty print the output."
     )
+    g.add_argument(
+        "--no-progress-bar",
+        action='store_true',
+        help="do not show the progress bar."
+    )
     g.add_argument(
         '-V',
         '--version',
